==> cost-interface-0.3.18-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/GuestReceiveMealsPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import java.io.Serializable;
import java.util.Date;

/**
 * 来宾用餐明细
 * GuestMealsInfo
 * 数据库表：guest_meals_info
 */
public class GuestReceiveMealsPayVo implements Serializable {

    private static final long serialVersionUID = 4044515238039594644L;
    /**
     * 
     * 表字段 : guest_meals_info.id
     */
    private Integer id;

    /**
     * 申请单号
     * 表字段 : guest_meals_info.apply_no
     */
    private String applyNo;

    /**
     * 日期
     * 表字段 : guest_meals_info.s_date
     */
    private Date sDate;

    /**
     * 早餐标准/人(分)
     * 表字段 : guest_meals_info.breakfast_cost
     */
    private Long breakfastCost;

    /**
     * 早餐费用/分
     * 表字段 : guest_meals_info.breakfast_amount
     */
    private Long breakfastAmount;

    /**
     * 早餐酒店
     * 表字段 : guest_meals_info.breakfast_hotal
     */
    private String breakfastHotal;

    /**
     * 酒店地址
     * 表字段 : guest_meals_info.breakfast_hotal_addr
     */
    private String breakfastHotalAddr;

    /**
     * 包厢/大厅
     * 表字段 : guest_meals_info.breakfast_hotal_local
     */
    private String breakfastHotalLocal;

    /**
     * 订餐电话
     * 表字段 : guest_meals_info.breakfast_order_tel
     */
    private String breakfastOrderTel;

    /**
     * 午餐标准/人(分)
     * 表字段 : guest_meals_info.lunch_cost
     */
    private Long lunchCost;

    /**
     * 午餐费用/分
     * 表字段 : guest_meals_info.lunch_amount
     */
    private Long lunchAmount;

    /**
     * 午餐酒店
     * 表字段 : guest_meals_info.lunch_hotal
     */
    private String lunchHotal;

    /**
     * 酒店地址
     * 表字段 : guest_meals_info.lunch_hotal_addr
     */
    private String lunchHotalAddr;

    /**
     * 包厢/大厅
     * 表字段 : guest_meals_info.lunch_hotal_local
     */
    private String lunchHotalLocal;

    /**
     * 订餐电话
     * 表字段 : guest_meals_info.lunch_order_tel
     */
    private String lunchOrderTel;

    /**
     * 晚餐标准/人(分)
     * 表字段 : guest_meals_info.dinner_cost
     */
    private Long dinnerCost;

    /**
     * 晚餐费用/分
     * 表字段 : guest_meals_info.dinner_amount
     */
    private Long dinnerAmount;

    /**
     * 晚餐酒店
     * 表字段 : guest_meals_info.dinner_hotal
     */
    private String dinnerHotal;

    /**
     * 酒店地址
     * 表字段 : guest_meals_info.dinner_hotal_addr
     */
    private String dinnerHotalAddr;

    /**
     * 包厢/大厅
     * 表字段 : guest_meals_info.dinner_hotal_local
     */
    private String dinnerHotalLocal;

    /**
     * 订餐电话
     * 表字段 : guest_meals_info.dinner_order_tel
     */
    private String dinnerOrderTel;

    /**
     * 
     * 表字段 : guest_meals_info.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : guest_meals_info.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : guest_meals_info.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : guest_meals_info.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : guest_meals_info.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : guest_meals_info.modify_date
     */
    private Date modifyDate;

    /**
     * 获取  字段:guest_meals_info.id
     *
     * @return guest_meals_info.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:guest_meals_info.id
     *
     * @param id the value for guest_meals_info.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 获取 申请单号 字段:guest_meals_info.apply_no
     *
     * @return guest_meals_info.apply_no, 申请单号
     */
    public String getApplyNo() {
        return applyNo;
    }

    /**
     * 设置 申请单号 字段:guest_meals_info.apply_no
     *
     * @param applyNo the value for guest_meals_info.apply_no, 申请单号
     */
    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    /**
     * 获取 日期 字段:guest_meals_info.s_date
     *
     * @return guest_meals_info.s_date, 日期
     */
    public Date getsDate() {
        return sDate;
    }

    /**
     * 设置 日期 字段:guest_meals_info.s_date
     *
     * @param sDate the value for guest_meals_info.s_date, 日期
     */
    public void setsDate(Date sDate) {
        this.sDate = sDate;
    }

    /**
     * 获取 早餐标准/人(分) 字段:guest_meals_info.breakfast_cost
     *
     * @return guest_meals_info.breakfast_cost, 早餐标准/人(分)
     */
    public Long getBreakfastCost() {
        return breakfastCost;
    }

    /**
     * 设置 早餐标准/人(分) 字段:guest_meals_info.breakfast_cost
     *
     * @param breakfastCost the value for guest_meals_info.breakfast_cost, 早餐标准/人(分)
     */
    public void setBreakfastCost(Long breakfastCost) {
        this.breakfastCost = breakfastCost;
    }

    /**
     * 获取 早餐费用/分 字段:guest_meals_info.breakfast_amount
     *
     * @return guest_meals_info.breakfast_amount, 早餐费用/分
     */
    public Long getBreakfastAmount() {
        return breakfastAmount;
    }

    /**
     * 设置 早餐费用/分 字段:guest_meals_info.breakfast_amount
     *
     * @param breakfastAmount the value for guest_meals_info.breakfast_amount, 早餐费用/分
     */
    public void setBreakfastAmount(Long breakfastAmount) {
        this.breakfastAmount = breakfastAmount;
    }

    /**
     * 获取 早餐酒店 字段:guest_meals_info.breakfast_hotal
     *
     * @return guest_meals_info.breakfast_hotal, 早餐酒店
     */
    public String getBreakfastHotal() {
        return breakfastHotal;
    }

    /**
     * 设置 早餐酒店 字段:guest_meals_info.breakfast_hotal
     *
     * @param breakfastHotal the value for guest_meals_info.breakfast_hotal, 早餐酒店
     */
    public void setBreakfastHotal(String breakfastHotal) {
        this.breakfastHotal = breakfastHotal;
    }

    /**
     * 获取 酒店地址 字段:guest_meals_info.breakfast_hotal_addr
     *
     * @return guest_meals_info.breakfast_hotal_addr, 酒店地址
     */
    public String getBreakfastHotalAddr() {
        return breakfastHotalAddr;
    }

    /**
     * 设置 酒店地址 字段:guest_meals_info.breakfast_hotal_addr
     *
     * @param breakfastHotalAddr the value for guest_meals_info.breakfast_hotal_addr, 酒店地址
     */
    public void setBreakfastHotalAddr(String breakfastHotalAddr) {
        this.breakfastHotalAddr = breakfastHotalAddr;
    }

    /**
     * 获取 包厢/大厅 字段:guest_meals_info.breakfast_hotal_local
     *
     * @return guest_meals_info.breakfast_hotal_local, 包厢/大厅
     */
    public String getBreakfastHotalLocal() {
        return breakfastHotalLocal;
    }

    /**
     * 设置 包厢/大厅 字段:guest_meals_info.breakfast_hotal_local
     *
     * @param breakfastHotalLocal the value for guest_meals_info.breakfast_hotal_local, 包厢/大厅
     */
    public void setBreakfastHotalLocal(String breakfastHotalLocal) {
        this.breakfastHotalLocal = breakfastHotalLocal;
    }

    /**
     * 获取 订餐电话 字段:guest_meals_info.breakfast_order_tel
     *
     * @return guest_meals_info.breakfast_order_tel, 订餐电话
     */
    public String getBreakfastOrderTel() {
        return breakfastOrderTel;
    }

    /**
     * 设置 订餐电话 字段:guest_meals_info.breakfast_order_tel
     *
     * @param breakfastOrderTel the value for guest_meals_info.breakfast_order_tel, 订餐电话
     */
    public void setBreakfastOrderTel(String breakfastOrderTel) {
        this.breakfastOrderTel = breakfastOrderTel;
    }

    /**
     * 获取 午餐标准/人(分) 字段:guest_meals_info.lunch_cost
     *
     * @return guest_meals_info.lunch_cost, 午餐标准/人(分)
     */
    public Long getLunchCost() {
        return lunchCost;
    }

    /**
     * 设置 午餐标准/人(分) 字段:guest_meals_info.lunch_cost
     *
     * @param lunchCost the value for guest_meals_info.lunch_cost, 午餐标准/人(分)
     */
    public void setLunchCost(Long lunchCost) {
        this.lunchCost = lunchCost;
    }

    /**
     * 获取 午餐费用/分 字段:guest_meals_info.lunch_amount
     *
     * @return guest_meals_info.lunch_amount, 午餐费用/分
     */
    public Long getLunchAmount() {
        return lunchAmount;
    }

    /**
     * 设置 午餐费用/分 字段:guest_meals_info.lunch_amount
     *
     * @param lunchAmount the value for guest_meals_info.lunch_amount, 午餐费用/分
     */
    public void setLunchAmount(Long lunchAmount) {
        this.lunchAmount = lunchAmount;
    }

    /**
     * 获取 午餐酒店 字段:guest_meals_info.lunch_hotal
     *
     * @return guest_meals_info.lunch_hotal, 午餐酒店
     */
    public String getLunchHotal() {
        return lunchHotal;
    }

    /**
     * 设置 午餐酒店 字段:guest_meals_info.lunch_hotal
     *
     * @param lunchHotal the value for guest_meals_info.lunch_hotal, 午餐酒店
     */
    public void setLunchHotal(String lunchHotal) {
        this.lunchHotal = lunchHotal;
    }

    /**
     * 获取 酒店地址 字段:guest_meals_info.lunch_hotal_addr
     *
     * @return guest_meals_info.lunch_hotal_addr, 酒店地址
     */
    public String getLunchHotalAddr() {
        return lunchHotalAddr;
    }

    /**
     * 设置 酒店地址 字段:guest_meals_info.lunch_hotal_addr
     *
     * @param lunchHotalAddr the value for guest_meals_info.lunch_hotal_addr, 酒店地址
     */
    public void setLunchHotalAddr(String lunchHotalAddr) {
        this.lunchHotalAddr = lunchHotalAddr;
    }

    /**
     * 获取 包厢/大厅 字段:guest_meals_info.lunch_hotal_local
     *
     * @return guest_meals_info.lunch_hotal_local, 包厢/大厅
     */
    public String getLunchHotalLocal() {
        return lunchHotalLocal;
    }

    /**
     * 设置 包厢/大厅 字段:guest_meals_info.lunch_hotal_local
     *
     * @param lunchHotalLocal the value for guest_meals_info.lunch_hotal_local, 包厢/大厅
     */
    public void setLunchHotalLocal(String lunchHotalLocal) {
        this.lunchHotalLocal = lunchHotalLocal;
    }

    /**
     * 获取 订餐电话 字段:guest_meals_info.lunch_order_tel
     *
     * @return guest_meals_info.lunch_order_tel, 订餐电话
     */
    public String getLunchOrderTel() {
        return lunchOrderTel;
    }

    /**
     * 设置 订餐电话 字段:guest_meals_info.lunch_order_tel
     *
     * @param lunchOrderTel the value for guest_meals_info.lunch_order_tel, 订餐电话
     */
    public void setLunchOrderTel(String lunchOrderTel) {
        this.lunchOrderTel = lunchOrderTel;
    }

    /**
     * 获取 晚餐标准/人(分) 字段:guest_meals_info.dinner_cost
     *
     * @return guest_meals_info.dinner_cost, 晚餐标准/人(分)
     */
    public Long getDinnerCost() {
        return dinnerCost;
    }

    /**
     * 设置 晚餐标准/人(分) 字段:guest_meals_info.dinner_cost
     *
     * @param dinnerCost the value for guest_meals_info.dinner_cost, 晚餐标准/人(分)
     */
    public void setDinnerCost(Long dinnerCost) {
        this.dinnerCost = dinnerCost;
    }

    /**
     * 获取 晚餐费用/分 字段:guest_meals_info.dinner_amount
     *
     * @return guest_meals_info.dinner_amount, 晚餐费用/分
     */
    public Long getDinnerAmount() {
        return dinnerAmount;
    }

    /**
     * 设置 晚餐费用/分 字段:guest_meals_info.dinner_amount
     *
     * @param dinnerAmount the value for guest_meals_info.dinner_amount, 晚餐费用/分
     */
    public void setDinnerAmount(Long dinnerAmount) {
        this.dinnerAmount = dinnerAmount;
    }

    /**
     * 获取 晚餐酒店 字段:guest_meals_info.dinner_hotal
     *
     * @return guest_meals_info.dinner_hotal, 晚餐酒店
     */
    public String getDinnerHotal() {
        return dinnerHotal;
    }

    /**
     * 设置 晚餐酒店 字段:guest_meals_info.dinner_hotal
     *
     * @param dinnerHotal the value for guest_meals_info.dinner_hotal, 晚餐酒店
     */
    public void setDinnerHotal(String dinnerHotal) {
        this.dinnerHotal = dinnerHotal;
    }

    /**
     * 获取 酒店地址 字段:guest_meals_info.dinner_hotal_addr
     *
     * @return guest_meals_info.dinner_hotal_addr, 酒店地址
     */
    public String getDinnerHotalAddr() {
        return dinnerHotalAddr;
    }

    /**
     * 设置 酒店地址 字段:guest_meals_info.dinner_hotal_addr
     *
     * @param dinnerHotalAddr the value for guest_meals_info.dinner_hotal_addr, 酒店地址
     */
    public void setDinnerHotalAddr(String dinnerHotalAddr) {
        this.dinnerHotalAddr = dinnerHotalAddr;
    }

    /**
     * 获取 包厢/大厅 字段:guest_meals_info.dinner_hotal_local
     *
     * @return guest_meals_info.dinner_hotal_local, 包厢/大厅
     */
    public String getDinnerHotalLocal() {
        return dinnerHotalLocal;
    }

    /**
     * 设置 包厢/大厅 字段:guest_meals_info.dinner_hotal_local
     *
     * @param dinnerHotalLocal the value for guest_meals_info.dinner_hotal_local, 包厢/大厅
     */
    public void setDinnerHotalLocal(String dinnerHotalLocal) {
        this.dinnerHotalLocal = dinnerHotalLocal;
    }

    /**
     * 获取 订餐电话 字段:guest_meals_info.dinner_order_tel
     *
     * @return guest_meals_info.dinner_order_tel, 订餐电话
     */
    public String getDinnerOrderTel() {
        return dinnerOrderTel;
    }

    /**
     * 设置 订餐电话 字段:guest_meals_info.dinner_order_tel
     *
     * @param dinnerOrderTel the value for guest_meals_info.dinner_order_tel, 订餐电话
     */
    public void setDinnerOrderTel(String dinnerOrderTel) {
        this.dinnerOrderTel = dinnerOrderTel;
    }

    /**
     * 获取  字段:guest_meals_info.create_id
     *
     * @return guest_meals_info.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:guest_meals_info.create_id
     *
     * @param createId the value for guest_meals_info.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:guest_meals_info.create_name
     *
     * @return guest_meals_info.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:guest_meals_info.create_name
     *
     * @param createName the value for guest_meals_info.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:guest_meals_info.create_date
     *
     * @return guest_meals_info.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:guest_meals_info.create_date
     *
     * @param createDate the value for guest_meals_info.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:guest_meals_info.modify_id
     *
     * @return guest_meals_info.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:guest_meals_info.modify_id
     *
     * @param modifyId the value for guest_meals_info.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:guest_meals_info.modify_name
     *
     * @return guest_meals_info.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:guest_meals_info.modify_name
     *
     * @param modifyName the value for guest_meals_info.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:guest_meals_info.modify_date
     *
     * @return guest_meals_info.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }

    /**
     * 设置  字段:guest_meals_info.modify_date
     *
     * @param modifyDate the value for guest_meals_info.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}

==> cost-interface-0.3.31-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/GuestReceiveMealsPayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import java.io.Serializable;
import java.util.Date;

/**
 * 来宾用餐明细
 * GuestMealsInfo
 * 数据库表：guest_meals_info
 */
public class GuestReceiveMealsPayVo implements Serializable {

    private static final long serialVersionUID = 4044515238039594644L;
    /**
     *
     * 表字段 : guest_meals_info.id
     */
    private Integer id;

    /**
     * 项目号
     * 表字段 : guest_meals_info.item_no
     */
    private Integer itemNo;

    /**
     * 申请单号
     * 表字段 : guest_meals_info.apply_no
     */
    private String applyNo;

    /**
     * 日期
     * 表字段 : guest_meals_info.s_date
     */
    private Date sDate;

    /**
     * 早餐标准/人(分)
     * 表字段 : guest_meals_info.breakfast_cost
     */
    private Long breakfastCost;

    /**
     * 早餐费用/分
     * 表字段 : guest_meals_info.breakfast_amount
     */
    private Long breakfastAmount;

    /**
     * 早餐酒店
     * 表字段 : guest_meals_info.breakfast_hotal
     */
    private String breakfastHotal;

    /**
     * 酒店地址
     * 表字段 : guest_meals_info.breakfast_hotal_addr
     */
    private String breakfastHotalAddr;

    /**
     * 包厢/大厅
     * 表字段 : guest_meals_info.breakfast_hotal_local
     */
    private String breakfastHotalLocal;

    /**
     * 订餐电话
     * 表字段 : guest_meals_info.breakfast_order_tel
     */
    private String breakfastOrderTel;

    /**
     * 午餐标准/人(分)
     * 表字段 : guest_meals_info.lunch_cost
     */
    private Long lunchCost;

    /**
     * 午餐费用/分
     * 表字段 : guest_meals_info.lunch_amount
     */
    private Long lunchAmount;

    /**
     * 午餐酒店
     * 表字段 : guest_meals_info.lunch_hotal
     */
    private String lunchHotal;

    /**
     * 酒店地址
     * 表字段 : guest_meals_info.lunch_hotal_addr
     */
    private String lunchHotalAddr;

    /**
     * 包厢/大厅
     * 表字段 : guest_meals_info.lunch_hotal_local
     */
    private String lunchHotalLocal;

    /**
     * 订餐电话
     * 表字段 : guest_meals_info.lunch_order_tel
     */
    private String lunchOrderTel;

    /**
     * 晚餐标准/人(分)
     * 表字段 : guest_meals_info.dinner_cost
     */
    private Long dinnerCost;

    /**
     * 晚餐费用/分
     * 表字段 : guest_meals_info.dinner_amount
     */
    private Long dinnerAmount;

    /**
     * 晚餐酒店
     * 表字段 : guest_meals_info.dinner_hotal
     */
    private String dinnerHotal;

    /**
     * 酒店地址
     * 表字段 : guest_meals_info.dinner_hotal_addr
     */
    private String dinnerHotalAddr;

    /**
     * 包厢/大厅
     * 表字段 : guest_meals_info.dinner_hotal_local
     */
    private String dinnerHotalLocal;

    /**
     * 订餐电话
     * 表字段 : guest_meals_info.dinner_order_tel
     */
    private String dinnerOrderTel;

    /**
     *
     * 表字段 : guest_meals_info.create_id
     */
    private String createId;

    /**
     *
     * 表字段 : guest_meals_info.create_name
     */
    private String createName;

    /**
     *
     * 表字段 : guest_meals_info.create_date
     */
    private Date createDate;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getItemNo() {
        return itemNo;
    }

    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    public String getApplyNo() {
        return applyNo;
    }

    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    public Date getsDate() {
        return sDate;
    }

    public void setsDate(Date sDate) {
        this.sDate = sDate;
    }

    public Long getBreakfastCost() {
        return breakfastCost;
    }

    public void setBreakfastCost(Long breakfastCost) {
        this.breakfastCost = breakfastCost;
    }

    public Long getBreakfastAmount() {
        return breakfastAmount;
    }

    public void setBreakfastAmount(Long breakfastAmount) {
        this.breakfastAmount = breakfastAmount;
    }

    public String getBreakfastHotal() {
        return breakfastHotal;
    }

    public void setBreakfastHotal(String breakfastHotal) {
        this.breakfastHotal = breakfastHotal;
    }

    public String getBreakfastHotalAddr() {
        return breakfastHotalAddr;
    }

    public void setBreakfastHotalAddr(String breakfastHotalAddr) {
        this.breakfastHotalAddr = breakfastHotalAddr;
    }

    public String getBreakfastHotalLocal() {
        return breakfastHotalLocal;
    }

    public void setBreakfastHotalLocal(String breakfastHotalLocal) {
        this.breakfastHotalLocal = breakfastHotalLocal;
    }

    public String getBreakfastOrderTel() {
        return breakfastOrderTel;
    }

    public void setBreakfastOrderTel(String breakfastOrderTel) {
        this.breakfastOrderTel = breakfastOrderTel;
    }

    public Long getLunchCost() {
        return lunchCost;
    }

    public void setLunchCost(Long lunchCost) {
        this.lunchCost = lunchCost;
    }

    public Long getLunchAmount() {
        return lunchAmount;
    }

    public void setLunchAmount(Long lunchAmount) {
        this.lunchAmount = lunchAmount;
    }

    public String getLunchHotal() {
        return lunchHotal;
    }

    public void setLunchHotal(String lunchHotal) {
        this.lunchHotal = lunchHotal;
    }

    public String getLunchHotalAddr() {
        return lunchHotalAddr;
    }

    public void setLunchHotalAddr(String lunchHotalAddr) {
        this.lunchHotalAddr = lunchHotalAddr;
    }

    public String getLunchHotalLocal() {
        return lunchHotalLocal;
    }

    public void setLunchHotalLocal(String lunchHotalLocal) {
        this.lunchHotalLocal = lunchHotalLocal;
    }

    public String getLunchOrderTel() {
        return lunchOrderTel;
    }

    public void setLunchOrderTel(String lunchOrderTel) {
        this.lunchOrderTel = lunchOrderTel;
    }

    public Long getDinnerCost() {
        return dinnerCost;
    }

    public void setDinnerCost(Long dinnerCost) {
        this.dinnerCost = dinnerCost;
    }

    public Long getDinnerAmount() {
        return dinnerAmount;
    }

    public void setDinnerAmount(Long dinnerAmount) {
        this.dinnerAmount = dinnerAmount;
    }

    public String getDinnerHotal() {
        return dinnerHotal;
    }

    public void setDinnerHotal(String dinnerHotal) {
        this.dinnerHotal = dinnerHotal;
    }

    public String getDinnerHotalAddr() {
        return dinnerHotalAddr;
    }

    public void setDinnerHotalAddr(String dinnerHotalAddr) {
        this.dinnerHotalAddr = dinnerHotalAddr;
    }

    public String getDinnerHotalLocal() {
        return dinnerHotalLocal;
    }

    public void setDinnerHotalLocal(String dinnerHotalLocal) {
        this.dinnerHotalLocal = dinnerHotalLocal;
    }

    public String getDinnerOrderTel() {
        return dinnerOrderTel;
    }

    public void setDinnerOrderTel(String dinnerOrderTel) {
        this.dinnerOrderTel = dinnerOrderTel;
    }

    public String getCreateId() {
        return createId;
    }

    public void setCreateId(String createId) {
        this.createId = createId;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }
}
